@@ -5,8 +5,7 @@
  * Main Metakit library include file
  */
 
-#ifndef __MK4_H__
-#define __MK4_H__
+#pragma once
 
 //---------------------------------------------------------------------------
 //
@@ -1088,4 +1087,3 @@ FILE *f4_LogPropMods(FILE *fp_, int propId_);
 
 //---------------------------------------------------------------------------
 
-#endif // __MK4_H__
